@@ -73,6 +73,7 @@ use super::helpers::{is_pytest_parametrize, split_names};
 /// - [`pytest` documentation: How to parametrize fixtures and test functions](https://docs.pytest.org/en/latest/how-to/parametrize.html#pytest-mark-parametrize)
 #[violation]
 pub struct PytestParametrizeNamesWrongType {
+    single_argument: bool,
     expected: types::ParametrizeNameType,
 }
 
@@ -81,13 +82,43 @@ impl Violation for PytestParametrizeNamesWrongType {
 
     #[derive_message_formats]
     fn message(&self) -> String {
-        let PytestParametrizeNamesWrongType { expected } = self;
-        format!("Wrong name(s) type in `@pytest.mark.parametrize`, expected `{expected}`")
+        let PytestParametrizeNamesWrongType {
+            single_argument,
+            expected,
+        } = self;
+        let expected_string = {
+            if *single_argument {
+                "`str`".to_string()
+            } else {
+                match expected {
+                    types::ParametrizeNameType::Csv => format!("a {expected}"),
+                    types::ParametrizeNameType::Tuple | types::ParametrizeNameType::List => {
+                        format!("`{expected}`")
+                    }
+                }
+            }
+        };
+        format!("Wrong type passed to first argument of `@pytest.mark.parametrize`; expected {expected_string}")
     }
 
     fn fix_title(&self) -> Option<String> {
-        let PytestParametrizeNamesWrongType { expected } = self;
-        Some(format!("Use a `{expected}` for parameter names"))
+        let PytestParametrizeNamesWrongType {
+            single_argument,
+            expected,
+        } = self;
+        let expected_string = {
+            if *single_argument {
+                "string".to_string()
+            } else {
+                match expected {
+                    types::ParametrizeNameType::Csv => format!("{expected}"),
+                    types::ParametrizeNameType::Tuple | types::ParametrizeNameType::List => {
+                        format!("`{expected}`")
+                    }
+                }
+            }
+        };
+        Some(format!("Use a {expected_string} for the first argument"))
     }
 }
 
@@ -182,11 +213,18 @@ pub struct PytestParametrizeValuesWrongType {
 }
 
 impl Violation for PytestParametrizeValuesWrongType {
+    const FIX_AVAILABILITY: FixAvailability = FixAvailability::Sometimes;
+
     #[derive_message_formats]
     fn message(&self) -> String {
         let PytestParametrizeValuesWrongType { values, row } = self;
         format!("Wrong values type in `@pytest.mark.parametrize` expected `{values}` of `{row}`")
     }
+
+    fn fix_title(&self) -> Option<String> {
+        let PytestParametrizeValuesWrongType { values, row } = self;
+        Some(format!("Use `{values}` of `{row}` for parameter values"))
+    }
 }
 
 /// ## What it does
@@ -321,6 +359,7 @@ fn check_names(checker: &mut Checker, decorator: &Decorator, expr: &Expr) {
                         .unwrap_or(expr.range());
                         let mut diagnostic = Diagnostic::new(
                             PytestParametrizeNamesWrongType {
+                                single_argument: false,
                                 expected: names_type,
                             },
                             name_range,
@@ -355,6 +394,7 @@ fn check_names(checker: &mut Checker, decorator: &Decorator, expr: &Expr) {
                         .unwrap_or(expr.range());
                         let mut diagnostic = Diagnostic::new(
                             PytestParametrizeNamesWrongType {
+                                single_argument: false,
                                 expected: names_type,
                             },
                             name_range,
@@ -393,6 +433,7 @@ fn check_names(checker: &mut Checker, decorator: &Decorator, expr: &Expr) {
                     types::ParametrizeNameType::List => {
                         let mut diagnostic = Diagnostic::new(
                             PytestParametrizeNamesWrongType {
+                                single_argument: false,
                                 expected: names_type,
                             },
                             expr.range(),
@@ -411,6 +452,7 @@ fn check_names(checker: &mut Checker, decorator: &Decorator, expr: &Expr) {
                     types::ParametrizeNameType::Csv => {
                         let mut diagnostic = Diagnostic::new(
                             PytestParametrizeNamesWrongType {
+                                single_argument: false,
                                 expected: names_type,
                             },
                             expr.range(),
@@ -437,6 +479,7 @@ fn check_names(checker: &mut Checker, decorator: &Decorator, expr: &Expr) {
                     types::ParametrizeNameType::Tuple => {
                         let mut diagnostic = Diagnostic::new(
                             PytestParametrizeNamesWrongType {
+                                single_argument: false,
                                 expected: names_type,
                             },
                             expr.range(),
@@ -456,6 +499,7 @@ fn check_names(checker: &mut Checker, decorator: &Decorator, expr: &Expr) {
                     types::ParametrizeNameType::Csv => {
                         let mut diagnostic = Diagnostic::new(
                             PytestParametrizeNamesWrongType {
+                                single_argument: false,
                                 expected: names_type,
                             },
                             expr.range(),
@@ -493,13 +537,46 @@ fn check_values(checker: &mut Checker, names: &Expr, values: &Expr) {
     match values {
         Expr::List(ast::ExprList { elts, .. }) => {
             if values_type != types::ParametrizeValuesType::List {
-                checker.diagnostics.push(Diagnostic::new(
+                let mut diagnostic = Diagnostic::new(
                     PytestParametrizeValuesWrongType {
                         values: values_type,
                         row: values_row_type,
                     },
                     values.range(),
-                ));
+                );
+                diagnostic.set_fix({
+                    // Determine whether the last element has a trailing comma. Single-element
+                    // tuples _require_ a trailing comma, so this is a single-element list
+                    // _without_ a trailing comma, we need to insert one.
+                    let needs_trailing_comma = if let [item] = elts.as_slice() {
+                        SimpleTokenizer::new(
+                            checker.locator().contents(),
+                            TextRange::new(item.end(), values.end()),
+                        )
+                        .all(|token| token.kind != SimpleTokenKind::Comma)
+                    } else {
+                        false
+                    };
+
+                    // Replace `[` with `(`.
+                    let values_start = Edit::replacement(
+                        "(".into(),
+                        values.start(),
+                        values.start() + TextSize::from(1),
+                    );
+                    // Replace `]` with `)` or `,)`.
+                    let values_end = Edit::replacement(
+                        if needs_trailing_comma {
+                            "),".into()
+                        } else {
+                            ")".into()
+                        },
+                        values.end() - TextSize::from(1),
+                        values.end(),
+                    );
+                    Fix::unsafe_edits(values_start, [values_end])
+                });
+                checker.diagnostics.push(diagnostic);
             }
 
             if is_multi_named {
@@ -508,14 +585,48 @@ fn check_values(checker: &mut Checker, names: &Expr, values: &Expr) {
         }
         Expr::Tuple(ast::ExprTuple { elts, .. }) => {
             if values_type != types::ParametrizeValuesType::Tuple {
-                checker.diagnostics.push(Diagnostic::new(
+                let mut diagnostic = Diagnostic::new(
                     PytestParametrizeValuesWrongType {
                         values: values_type,
                         row: values_row_type,
                     },
                     values.range(),
-                ));
+                );
+                diagnostic.set_fix({
+                    // Determine whether a trailing comma is present due to the _requirement_
+                    // that a single-element tuple must have a trailing comma, e.g., `(1,)`.
+                    //
+                    // If the trailing comma is on its own line, we intentionally ignore it,
+                    // since the expression is already split over multiple lines, as in:
+                    // ```python
+                    // @pytest.mark.parametrize(
+                    //     (
+                    //         "x",
+                    //     ),
+                    // )
+                    // ```
+                    let has_trailing_comma = elts.len() == 1
+                        && checker.locator().up_to(values.end()).chars().rev().nth(1) == Some(',');
+
+                    // Replace `(` with `[`.
+                    let values_start = Edit::replacement(
+                        "[".into(),
+                        values.start(),
+                        values.start() + TextSize::from(1),
+                    );
+                    // Replace `)` or `,)` with `]`.
+                    let start = if has_trailing_comma {
+                        values.end() - TextSize::from(2)
+                    } else {
+                        values.end() - TextSize::from(1)
+                    };
+                    let values_end = Edit::replacement("]".into(), start, values.end());
+
+                    Fix::unsafe_edits(values_start, [values_end])
+                });
+                checker.diagnostics.push(diagnostic);
             }
+
             if is_multi_named {
                 handle_value_rows(checker, elts, values_type, values_row_type);
             }
@@ -533,10 +644,15 @@ fn check_values(checker: &mut Checker, names: &Expr, values: &Expr) {
 ///              Tokenize this range to locate the comma.
 /// )
 /// ```
-fn trailing_comma(element: &Expr, source: &str) -> Option<TextSize> {
-    SimpleTokenizer::starts_at(element.end(), source)
-        .find(|token| token.kind == SimpleTokenKind::Comma)
-        .map(|token| token.start())
+fn trailing_comma(element: &Expr, source: &str, max_index: TextSize) -> TextSize {
+    for token in SimpleTokenizer::starts_at(element.end(), source) {
+        if matches!(token.kind, SimpleTokenKind::Comma) {
+            return token.start();
+        } else if token.start() >= max_index {
+            return max_index;
+        }
+    }
+    max_index
 }
 
 /// PT014
@@ -561,9 +677,9 @@ fn check_duplicates(checker: &mut Checker, values: &Expr) {
                 if let Some(prev) = prev {
                     let values_end = values.end() - TextSize::new(1);
                     let previous_end =
-                        trailing_comma(prev, checker.locator().contents()).unwrap_or(values_end);
+                        trailing_comma(prev, checker.locator().contents(), values_end);
                     let element_end =
-                        trailing_comma(element, checker.locator().contents()).unwrap_or(values_end);
+                        trailing_comma(element, checker.locator().contents(), values_end);
                     let deletion_range = TextRange::new(previous_end, element_end);
                     if !checker
                         .indexer()
@@ -583,6 +699,7 @@ fn check_duplicates(checker: &mut Checker, values: &Expr) {
 fn handle_single_name(checker: &mut Checker, expr: &Expr, value: &Expr) {
     let mut diagnostic = Diagnostic::new(
         PytestParametrizeNamesWrongType {
+            single_argument: true,
             expected: types::ParametrizeNameType::Csv,
         },
         expr.range(),
@@ -604,26 +721,91 @@ fn handle_value_rows(
 ) {
     for elt in elts {
         match elt {
-            Expr::Tuple(_) => {
+            Expr::Tuple(ast::ExprTuple { elts, .. }) => {
                 if values_row_type != types::ParametrizeValuesRowType::Tuple {
-                    checker.diagnostics.push(Diagnostic::new(
+                    let mut diagnostic = Diagnostic::new(
                         PytestParametrizeValuesWrongType {
                             values: values_type,
                             row: values_row_type,
                         },
                         elt.range(),
-                    ));
+                    );
+                    diagnostic.set_fix({
+                        // Determine whether a trailing comma is present due to the _requirement_
+                        // that a single-element tuple must have a trailing comma, e.g., `(1,)`.
+                        //
+                        // If the trailing comma is on its own line, we intentionally ignore it,
+                        // since the expression is already split over multiple lines, as in:
+                        // ```python
+                        // @pytest.mark.parametrize(
+                        //     (
+                        //         "x",
+                        //     ),
+                        // )
+                        // ```
+                        let has_trailing_comma = elts.len() == 1
+                            && checker.locator().up_to(elt.end()).chars().rev().nth(1) == Some(',');
+
+                        // Replace `(` with `[`.
+                        let elt_start = Edit::replacement(
+                            "[".into(),
+                            elt.start(),
+                            elt.start() + TextSize::from(1),
+                        );
+                        // Replace `)` or `,)` with `]`.
+                        let start = if has_trailing_comma {
+                            elt.end() - TextSize::from(2)
+                        } else {
+                            elt.end() - TextSize::from(1)
+                        };
+                        let elt_end = Edit::replacement("]".into(), start, elt.end());
+                        Fix::unsafe_edits(elt_start, [elt_end])
+                    });
+                    checker.diagnostics.push(diagnostic);
                 }
             }
-            Expr::List(_) => {
+            Expr::List(ast::ExprList { elts, .. }) => {
                 if values_row_type != types::ParametrizeValuesRowType::List {
-                    checker.diagnostics.push(Diagnostic::new(
+                    let mut diagnostic = Diagnostic::new(
                         PytestParametrizeValuesWrongType {
                             values: values_type,
                             row: values_row_type,
                         },
                         elt.range(),
-                    ));
+                    );
+                    diagnostic.set_fix({
+                        // Determine whether the last element has a trailing comma. Single-element
+                        // tuples _require_ a trailing comma, so this is a single-element list
+                        // _without_ a trailing comma, we need to insert one.
+                        let needs_trailing_comma = if let [item] = elts.as_slice() {
+                            SimpleTokenizer::new(
+                                checker.locator().contents(),
+                                TextRange::new(item.end(), elt.end()),
+                            )
+                            .all(|token| token.kind != SimpleTokenKind::Comma)
+                        } else {
+                            false
+                        };
+
+                        // Replace `[` with `(`.
+                        let elt_start = Edit::replacement(
+                            "(".into(),
+                            elt.start(),
+                            elt.start() + TextSize::from(1),
+                        );
+                        // Replace `]` with `)` or `,)`.
+                        let elt_end = Edit::replacement(
+                            if needs_trailing_comma {
+                                ",)".into()
+                            } else {
+                                ")".into()
+                            },
+                            elt.end() - TextSize::from(1),
+                            elt.end(),
+                        );
+                        Fix::unsafe_edits(elt_start, [elt_end])
+                    });
+                    checker.diagnostics.push(diagnostic);
                 }
             }
             _ => {}
