@@ -1,6 +1,7 @@
 pub(crate) use bit_count::*;
 pub(crate) use check_and_remove_from_set::*;
 pub(crate) use delete_full_slice::*;
+pub(crate) use for_loop_set_mutations::*;
 pub(crate) use hashlib_digest_hex::*;
 pub(crate) use if_expr_min_max::*;
 pub(crate) use implicit_cwd::*;
@@ -20,10 +21,13 @@ pub(crate) use single_item_membership_test::*;
 pub(crate) use slice_copy::*;
 pub(crate) use type_none_comparison::*;
 pub(crate) use unnecessary_enumerate::*;
+pub(crate) use unnecessary_from_float::*;
+pub(crate) use verbose_decimal_constructor::*;
 
 mod bit_count;
 mod check_and_remove_from_set;
 mod delete_full_slice;
+mod for_loop_set_mutations;
 mod hashlib_digest_hex;
 mod if_expr_min_max;
 mod implicit_cwd;
@@ -43,3 +47,5 @@ mod single_item_membership_test;
 mod slice_copy;
 mod type_none_comparison;
 mod unnecessary_enumerate;
+mod unnecessary_from_float;
+mod verbose_decimal_constructor;
