@@ -4,7 +4,7 @@ use ruff_python_trivia::{PythonWhitespace, SimpleTokenKind, SimpleTokenizer};
 use ruff_text_size::{Ranged, TextLen, TextRange, TextSize};
 
 use crate::comments::SourceComment;
-use crate::expression::expr_generator_exp::GeneratorExpParentheses;
+use crate::expression::expr_generator::GeneratorExpParentheses;
 use crate::expression::is_expression_huggable;
 use crate::expression::parentheses::{empty_parenthesized, parenthesized, Parentheses};
 use crate::other::commas;
@@ -40,7 +40,7 @@ impl FormatNodeRule<Arguments> for FormatArguments {
             match args.as_ref() {
                 [arg] if keywords.is_empty() => {
                     match arg {
-                        Expr::GeneratorExp(generator_exp) => joiner.entry(
+                        Expr::Generator(generator_exp) => joiner.entry(
                             generator_exp,
                             &generator_exp
                                 .format()
@@ -205,11 +205,7 @@ fn is_arguments_huggable(arguments: &Arguments, context: &PyFormatContext) -> bo
 
     // If the expression has a trailing comma, then we can't hug it.
     if options.magic_trailing_comma().is_respect()
-        && commas::has_magic_trailing_comma(
-            TextRange::new(arg.end(), arguments.end()),
-            options,
-            context,
-        )
+        && commas::has_magic_trailing_comma(TextRange::new(arg.end(), arguments.end()), context)
     {
         return false;
     }
